[Zodb-checkins] CVS: Zope3/src/zope/testing - doctestunit.py:1.2
Jim Fulton
jim at zope.com
Sun May 18 15:27:02 EDT 2003
Update of /cvs-repository/Zope3/src/zope/testing
In directory cvs.zope.org:/tmp/cvs-serv14377
Modified Files:
doctestunit.py
Log Message:
Improved the doc strings.
=== Zope3/src/zope/testing/doctestunit.py 1.1 => 1.2 ===
--- Zope3/src/zope/testing/doctestunit.py:1.1 Sun May 18 13:53:06 2003
+++ Zope3/src/zope/testing/doctestunit.py Sun May 18 14:27:01 2003
@@ -169,6 +169,13 @@
return expect
def testsource(module, name):
+ """Extract the test sources from a doctest test docstring as a script
+
+ Provide the module (or dotted name of the module) containing the
+ test to be debugged and the name (within the module) of the object
+ with the doc string with tests to be debugged.
+
+ """
module = _normalizeModule(module)
tests = _findTests(module, "")
test = [doc for (tname, doc, f, l) in tests if tname == name]
@@ -184,7 +191,12 @@
return testsrc
def debug(module, name):
- """Debug a single doctest test
+ """Debug a single doctest test doc string
+
+ Provide the module (or dotted name of the module) containing the
+ test to be debugged and the name (within the module) of the object
+ with the doc string with tests to be debugged.
+
"""
module = _normalizeModule(module)
testsrc = testsource(module, name)
More information about the Zodb-checkins
mailing list